==> spip_3.2.11.orig.tar.xz: plugins-dist/sites/lang/sites_cpf.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/sites?lang_cible=cpf
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_echec_syndication_01' => 'Sindikasyon-la la giny pa marsé : lé inposib lir lo "backend" ou la doné, oubyensa li néna pwind zartik propozé.',
	'avis_echec_syndication_02' => 'Sindikasyon-la, la giny pa marsé : larivé dann "backend" sit-la lé inposib.',
	'avis_site_introuvable' => 'Lé pa posib trouv sitwèb-la',
	'avis_site_syndique_probleme' => 'Tansyon pangar : lasindikasyon sitwèb-la, néna trov inn larlik ; astèr, sistèm la défalké pou inn ti moman. Véy byin ladrès lo fisyé lasindicasyon lé bon, pou lo sit-la : (<b>@url_syndic@</b>). Si ou vé, ou i pé eséy inn nouvèl rékupèrasyon do bann zinformasyon.', # MODIF
	'avis_sites_probleme_syndication' => 'Bann sitwèb-la néna giny inn larlik pou lasindikasyon.',
	'avis_sites_syndiques_probleme' => 'Bann sitwèb sak néna inn larlik ',

	// B
	'bouton_radio_modere_posteriori' => 'lé modèré apré konfirmasyon ', # MODIF
	'bouton_radio_modere_priori' => 'lé modèré-dovan', # MODIF
	'bouton_radio_non_syndication' => 'Anpès lasindikasyon',
	'bouton_radio_syndication' => 'Lasindikasyon :',

	// E
	'entree_adresse_fichier_syndication' => 'Ladrès lo fisyé po lasindikasyon :',
	'entree_adresse_site' => '<b>Ladrès lo sitwèb</b> [Nésésèr]',
	'entree_description_site' => 'Kosa lé lo sitwèb-la',

	// F
	'form_prop_nom_site' => 'Non lo sitwèb',

	// I
	'icone_modifier_site' => 'Sanz lo sitwèb-la',
	'icone_referencer_nouveau_site' => 'Réfèrans inn nouvo sitwèb',
	'icone_voir_sites_references' => 'Vwar bann sit an gatiraz dann référansman',
	'info_1_site' => '1 sitwèb',
	'info_a_valider' => '[pou konfirmasyon]',
	'info_bloquer' => 'blok ali',
	'info_bloquer_lien' => 'blok lo gatiraz-la',
	'info_derniere_syndication' => 'Dernyèr lasindikasyon sit-la-minm la finn dèt asevé lo',
	'info_liens_syndiques_1' => 'gatir pou lasindikasyon',
	'info_liens_syndiques_2' => 'i espèr lakonfirmasyon.',
	'info_nom_site_2' => '<b>Non lo sitwèb/b> [Obligatwar]',
	'info_panne_site_syndique' => 'Lo sit sindiké-la lé an pan',
	'info_probleme_grave' => 'kanard èk',
	'info_question_proposer_site' => 'Kisa i pé propoz bann sit référansé ?',
	'info_retablir_lien' => 'Armèt lo gatir dégréné-la',
	'info_site_attente' => 'Sitwèb-la lé apré espèr lakonfirmasyon',
	'info_site_propose' => 'Sitwèb propozé lo :',
	'info_site_reference' => 'Sitwèb référansé an liyn',
	'info_site_refuse' => 'Sitwèb-la lé arfizé',
	'info_site_syndique' => 'Sitwèb-la lé sindiké...', # MODIF
	'info_site_valider' => 'Bann sitwèb pou konfirm',
	'info_sites_referencer' => 'Référans inn sitwèb',
	'info_sites_refuses' => 'Bann sitwèb lé arfizé',
	'info_statut_site_1' => 'Sitwèb-la lé :',
	'info_statut_site_2' => 'Publyé',
	'info_statut_site_3' => 'Propozé',
	'info_statut_site_4' => 'Dann korbéy', # MODIF
	'info_syndication' => 'Lasindikasyon :',
	'info_syndication_articles' => '(bann) lartik',
	'item_bloquer_liens_syndiques' => 'Blok bann gatir sindiké pou lakonfirmasyon',
	'item_gerer_annuaire_site_web' => 'Zèr inn karné pou bann sitwèb',
	'item_non_bloquer_liens_syndiques' => 'Anpès bloké bann gatir sak i vyind lasindikasyon',
	'item_non_gerer_annuaire_site_web' => 'Défalk lo karné bann sitwèb',
	'item_non_utiliser_syndication' => 'Anpès ansèrv lasindikasyon otomatik',
	'item_utiliser_syndication' => 'Ansèrv lasindikasyon otomatik',

	// L
	'lien_mise_a_jour_syndication' => 'Arnouvèl astèr toudswit',
	'lien_nouvelle_recuperation' => 'Esèy inn ot sarzman do bann doné.',

	// S
	'syndic_choix_moderation' => 'Kosa ou vé SPIP i fé èk bann gatiraj sat i pè sort sit-la plitar ?',
	'syndic_choix_oublier' => 'Kosa ou vé SPIP i fé èk bann gatiraj sat lé pli dann out fisyé-sindikasyon ?',
	'syndic_choix_resume' => 'Nenna desertin sit sat i donn lansanm zot ban zartik byen komplé.Eské oui vé sindik azot konsa :',
	'syndic_lien_obsolete' => 'gatiraj sat lé tro vié',
	'syndic_option_miroir' => 'blok azot otomatikman',
	'syndic_option_oubli' => 'efas azot (apré @mois@ mwa)',
	'syndic_option_resume_non' => 'lansamn byen komplé bann zartik (ek lo forma HTML)',
	'syndic_option_resume_oui' => 'in semp rézimé selman( elk lo forma teks )',
	'syndic_options' => 'Bann zopsyon pou la sindikasyon :',

	// T
	'texte_liens_sites_syndiques' => 'Bann gatiraz sak i sort bann sit sindiké, zot i
pé èt bloké dann modèr-dovan ; réglaz-la anba i indik lo réglaz otomatik pou bann sit sindiké kank zot la finn dèt kréé. Lé posib answit débloké sakinn gatiraz.Ou pé osi swazi bloké bann gatiraz pou inn sit byin kadré.', # MODIF
	'texte_messages_publics' => 'Bann modékri-déor pou lartik-la :',
	'texte_non_fonction_referencement' => 'Lé posib ou préfèr pa anserv lafonksyon-la akoz i lé otomatik : dann ka-la, ou pé indik ou-minm tout bann zéléman ou la désid sak i kosern lo sit...', # MODIF
	'texte_referencement_automatique' => '<b>Référansman otomatik pou inn sit</b><br />Ou pé référans vitman inn sitwèb. Pou sa minm, indik anba ladrès lo sit ou ladrès lo fisyé pou la sindikasyon. SPIP i sava rékupèr otomatikman bann zinformasyon sir lo sit minm (titr, kosa i sava trouv dodan...).', # MODIF
	'texte_syndication' => 'Lé posib rékupèr la list bann nouvelté otomatikman, sir désertin sit : ifo pou sa-la fé zwé lasindikasyon 
<blockquote><i>Néna désertin zéberzèr sak i dégrèn lafonksyon-la ; 
dann ka-la ou sra pa pou itiliz lasindikasyon d-kontnu
dopwi out pro sit sa-minm.</i></blockquote>', # MODIF
	'titre_articles_syndiques' => 'Bann zartik sindiké i sort lo sit-la',
	'titre_dernier_article_syndique' => 'Bann dernyé zartik sindiké',
	'titre_page_sites_tous' => 'Bann sitwèb référansé',
	'titre_referencement_sites' => 'Référansman èk lasindikasyon (sitwèb)',
	'titre_site_numero' => 'SITWÈB NIMÉRO :',
	'titre_sites_proposes' => 'Bann sitwèb propozé',
	'titre_sites_references_rubrique' => 'Bann sitwèb référansé dann rubrik-la',
	'titre_sites_syndiques' => 'Bann sitwèb sindiké',
	'titre_sites_tous' => 'List bann sitwèb référansé',
	'titre_syndication' => 'Sindikasyon bann sitwèb'
);

==> spip_4.4.6+dfsg.orig.tar.xz: plugins-dist/sites/lang/sites_cpf.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/sites?lang_cible=cpf
// ** ne pas modifier le fichier **

return [

	// A
	'avis_echec_syndication_01' => 'Sindikasyon-la la giny pa marsé : lé inposib lir lo "backend" ou la doné, oubyensa li néna pwind zartik propozé.',
	'avis_echec_syndication_02' => 'Sindikasyon-la, la giny pa marsé : larivé dann "backend" sit-la lé inposib.',
	'avis_site_introuvable' => 'Lé pa posib trouv sitwèb-la',
	'avis_site_syndique_probleme' => 'Tansyon pangar : lasindikasyon sitwèb-la, néna trov inn larlik ; astèr, sistèm la défalké pou inn ti moman. Véy byin ladrès lo fisyé lasindicasyon lé bon, pou lo sit-la : (<b>@url_syndic@</b>). Si ou vé, ou i pé eséy inn nouvèl rékupèrasyon do bann zinformasyon.', # MODIF
	'avis_sites_probleme_syndication' => 'Bann sitwèb-la néna giny inn larlik pou lasindikasyon.',
	'avis_sites_syndiques_probleme' => 'Bann sitwèb sak néna inn larlik ',

	// B
	'bouton_radio_modere_posteriori' => 'lé modèré apré konfirmasyon ', # MODIF
	'bouton_radio_modere_priori' => 'lé modèré-dovan', # MODIF
	'bouton_radio_non_syndication' => 'Anpès lasindikasyon',
	'bouton_radio_syndication' => 'Lasindikasyon :',

	// E
	'entree_adresse_fichier_syndication' => 'Ladrès lo fisyé po lasindikasyon :',
	'entree_adresse_site' => '<b>Ladrès lo sitwèb</b> [Nésésèr]',
	'entree_description_site' => 'Kosa lé lo sitwèb-la',

	// F
	'form_prop_nom_site' => 'Non lo sitwèb',

	// I
	'icone_modifier_site' => 'Sanz lo sitwèb-la',
	'icone_referencer_nouveau_site' => 'Réfèrans inn nouvo sitwèb',
	'icone_voir_sites_references' => 'Vwar bann sit an gatiraz dann référansman',
	'info_1_site' => '1 sitwèb',
	'info_a_valider' => '[pou konfirmasyon]',
	'info_bloquer' => 'blok ali',
	'info_bloquer_lien' => 'blok lo gatiraz-la',
	'info_derniere_syndication' => 'Dernyèr lasindikasyon sit-la-minm la finn dèt asevé lo',
	'info_liens_syndiques_1' => 'gatir pou lasindikasyon',
	'info_liens_syndiques_2' => 'i espèr lakonfirmasyon.',
	'info_nom_site_2' => '<b>Non lo sitwèb/b> [Obligatwar]',
	'info_panne_site_syndique' => 'Lo sit sindiké-la lé an pan',
	'info_probleme_grave' => 'kanard èk',
	'info_question_proposer_site' => 'Kisa i pé propoz bann sit référansé ?',
	'info_retablir_lien' => 'Armèt lo gatir dégréné-la',
	'info_site_attente' => 'Sitwèb-la lé apré espèr lakonfirmasyon',
	'info_site_propose' => 'Sitwèb propozé lo :',
	'info_site_reference' => 'Sitwèb référansé an liyn',
	'info_site_refuse' => 'Sitwèb-la lé arfizé',
	'info_site_syndique' => 'Sitwèb-la lé sindiké...', # MODIF
	'info_site_valider' => 'Bann sitwèb pou konfirm',
	'info_sites_referencer' => 'Référans inn sitwèb',
	'info_sites_refuses' => 'Bann sitwèb lé arfizé',
	'info_statut_site_1' => 'Sitwèb-la lé :',
	'info_statut_site_2' => 'Publyé',
	'info_statut_site_3' => 'Propozé',
	'info_statut_site_4' => 'Dann korbéy', # MODIF
	'info_syndication' => 'Lasindikasyon :',
	'info_syndication_articles' => '(bann) lartik',
	'item_bloquer_liens_syndiques' => 'Blok bann gatir sindiké pou lakonfirmasyon',
	'item_gerer_annuaire_site_web' => 'Zèr inn karné pou bann sitwèb',
	'item_non_bloquer_liens_syndiques' => 'Anpès bloké bann gatir sak i vyind lasindikasyon',
	'item_non_gerer_annuaire_site_web' => 'Défalk lo karné bann sitwèb',
	'item_non_utiliser_syndication' => 'Anpès ansèrv lasindikasyon otomatik',
	'item_utiliser_syndication' => 'Ansèrv lasindikasyon otomatik',

	// L
	'lien_mise_a_jour_syndication' => 'Arnouvèl astèr toudswit',
	'lien_nouvelle_recuperation' => 'Esèy inn ot sarzman do bann doné.',

	// S
	'syndic_choix_moderation' => 'Kosa ou vé SPIP i fé èk bann gatiraj sat i pè sort sit-la plitar ?',
	'syndic_choix_oublier' => 'Kosa ou vé SPIP i fé èk bann gatiraj sat lé pli dann out fisyé-sindikasyon ?',
	'syndic_choix_resume' => 'Nenna desertin sit sat i donn lansanm zot ban zartik byen komplé.Eské oui vé sindik azot konsa :',
	'syndic_lien_obsolete' => 'gatiraj sat lé tro vié',
	'syndic_option_miroir' => 'blok azot otomatikman',
	'syndic_option_oubli' => 'efas azot (apré @mois@ mwa)',
	'syndic_option_resume_non' => 'lansamn byen komplé bann zartik (ek lo forma HTML)',
	'syndic_option_resume_oui' => 'in semp rézimé selman( elk lo forma teks )',
	'syndic_options' => 'Bann zopsyon pou la sindikasyon :',

	// T
	'texte_liens_sites_syndiques' => 'Bann gatiraz sak i sort bann sit sindiké, zot i
pé èt bloké dann modèr-dovan ; réglaz-la anba i indik lo réglaz otomatik pou bann sit sindiké kank zot la finn dèt kréé. Lé posib answit débloké sakinn gatiraz.Ou pé osi swazi bloké bann gatiraz pou inn sit byin kadré.', # MODIF
	'texte_messages_publics' => 'Bann modékri-déor pou lartik-la :',
	'texte_non_fonction_referencement' => 'Lé posib ou préfèr pa anserv lafonksyon-la akoz i lé otomatik : dann ka-la, ou pé indik ou-minm tout bann zéléman ou la désid sak i kosern lo sit...', # MODIF
	'texte_referencement_automatique' => '<b>Référansman otomatik pou inn sit</b><br />Ou pé référans vitman inn sitwèb. Pou sa minm, indik anba ladrès lo sit ou ladrès lo fisyé pou la sindikasyon. SPIP i sava rékupèr otomatikman bann zinformasyon sir lo sit minm (titr, kosa i sava trouv dodan...).', # MODIF
	'texte_syndication' => 'Lé posib rékupèr la list bann nouvelté otomatikman, sir désertin sit : ifo pou sa-la fé zwé lasindikasyon 
<blockquote><i>Néna désertin zéberzèr sak i dégrèn lafonksyon-la ; 
dann ka-la ou sra pa pou itiliz lasindikasyon d-kontnu
dopwi out pro sit sa-minm.</i></blockquote>', # MODIF
	'titre_articles_syndiques' => 'Bann zartik sindiké i sort lo sit-la',
	'titre_dernier_article_syndique' => 'Bann dernyé zartik sindiké',
	'titre_page_sites_tous' => 'Bann sitwèb référansé',
	'titre_referencement_sites' => 'Référansman èk lasindikasyon (sitwèb)',
	'titre_site_numero' => 'SITWÈB NIMÉRO :',
	'titre_sites_proposes' => 'Bann sitwèb propozé',
	'titre_sites_references_rubrique' => 'Bann sitwèb référansé dann rubrik-la',
	'titre_sites_syndiques' => 'Bann sitwèb sindiké',
	'titre_sites_tous' => 'List bann sitwèb référansé',
	'titre_syndication' => 'Sindikasyon bann sitwèb',
];
